function [A,B,C,D] = linearizedModel(P, x2, x3, p_man, u1, u2, H0)
% This function generates the linearized model 
% (5.3) - (5.4). 

%% System parameters
beta1   = P.beta1;
beta2   = P.beta2;
V1      = P.V1;
V2      = P.V2;
PI      = P.PI;
Kc      = P.Kc;
Aavr    = P.Aavg;
A1      = Aavr;
A2      = Aavr;
rhoAvg  = P.rhoAvg;
rho1    = P.rho1;
rho2    = P.rho2;
lAvr    = P.lavr;
B0_1    = P.B0_1;
B1_1    = P.B1_1;
B0_2    = P.B0_2;
B1_2    = P.B1_2;
f0      = 50;
g       = P.g;

%% Matrix entries
a11 = (beta1*PI)/V1;
a13 = beta1/V1;
a22 = 0.5*(beta2/V2)*Kc*(x2-p_man)^(-0.5)*u2;
a23 = beta2/V2;
a31 = Aavr/(rhoAvg*lAvr);
a32 = Aavr/(rhoAvg*lAvr);
a33 = (((B0_1 +B1_1)*rho1/A1) + ((B0_2 +B1_2)*rho2/A2))*x3;
b22 = (beta2/V2)*Kc*(x2-p_man)^(0.5);
b31 = (Aavr/(rhoAvg*lAvr))*((rho2*g)/f0^2)*H0*2*u1;
c12 = 1;
c13 = 2*((B0_1 +B1_1)/A1)*(rho2/2)*x3;
d12 = ((rho2*g)/f0^2)*H0*2*u1;

%% Matrices
A = [-a11,0,-a13;
    0,-a22,a23;
    a31,-a32,-a33];

B = [0,0;
    0,b22;
    b31,0];

C = [0,c12,c13];

D = [d12,0];




end

