function [M,varargout] = CreateManifold(pressure, varargin )
% This function create a new manifold and transportation line

%% Manifold struct M with associated parameters
M.Vman = 0.1*10;                        % [m^3] Manifold volume
M.beta_man = 8.3022e+006;               % Bulk modulus
M.p = pressure;                         % [Pa] Manifold pressure
M.dt = 0.05;                            % [s] Step size
M.q = 0;                                % [m^3/s] Initial inflow
M.q_wv = 0;                             % [%] Initial water cut
M.avrWC = 0;                            % [%] Initial, average water cut
M.avrMU = 0;                            % Average viscosity
M.f = 56;                               % [Hz] (Actual) Booster-pump frequency
M.fRef = 56;                            % [Hz] (Desired) Booster-pump frequency
M.dfMAX = 0.25;                         % [Hz/s] Frequency rate limitations


%% Transportation line parameters
M.l_TL = 0.5*10^(3);                      % [m] Length of transportation line
M.p_topside = 10^5;                       % [Pa] Topside condition
M.rAvg = 1*0.059500000000000;             % [m] Average radius
M.Aavg = pi*M.rAvg^2;                     % [m^2] Average cross section area
M.rho = 984;                              % [kg/m^3] Density (booster pump - topside facility)
M.M = 1.658042339059441e+08;



%% Calculate necessaray data
% Number of wells in the system
Nwells = nargin-1;

for i=1:Nwells
    P = varargin{i};
    P.p(6) = M.p; 
    M.q = M.q + P.q_c;
    varargout{i} = P;  
end

for i=1:Nwells
    P = varargin{i};
    M.avrWC = M.avrWC + (P.q_c/M.q)*P.WC; 
    M.avrMU = M.avrMU + (P.q_c/M.q)*P.mu_2; 
end

M = WaterFeedControl(M);
    
M.q_bp = M.q;

%% Calculate transportation line data based on manifold data
Gf_TL = TLFriction(M);
M.pOut_bp = M.p_topside + Gf_TL;            % [Pa] Static pressure






    

end

