function [M] = SolveDiffEqManifold(M,Tsolver)
% This function simulates the manifold 
% differential equations

global DXM
x0 = [M.p,M.q_bp,M.f]';             % Set current state as initial condition
M.DpBP = dpBP(M.f);     % Calculate differential pressure across BP

    
    
%% Solve differential equation
A = ode4(@(t, x) DiffEqManifold(x,M),Tsolver, x0)';  
M.p = A(1,end);                 % Next M.p
M.q_bp = A(2,end);              % Next M.q_bp
M.f = A(3,end);                 % Next M.f


% DXM

end

function [dx] = DiffEqManifold(p,M)
% This function represent the differential 
% equations (3.37), (3.38) and (3.41)
global DXM

Gf_TL = TLFriction(M);
df_bp = (M.fRef - M.f)/M.dt;

dx(1) = (M.beta_man/M.Vman)*(M.q-M.q_bp);
dx(2) = (1/M.M)*(M.p  - M.p_topside - Gf_TL+ M.DpBP);
    
if abs(df_bp) > M.dfMAX
    dx(3) = sign(df_bp)*M.dfMAX;
else
     dx(3) = df_bp;
end

    dx = dx';
    DXM = dx;
end