function [P] = CalculateBounds( P)
% This function calculates the delimitations
% of the operational envelope

f1 = 35;
f2 = 65;
P.g = 9.81;
P.rho2 = 984;
P.nStages = 64;

%% Points of intersection
A1 = 33.38;     A11= 52.61;
A2 = 61.67;     A22= 166.5;
A3 = 95.15;     A33= 99.81;
A4 = 63.1;      A44= 33.84;

L12 = polyfit(linspace(A1, A2,1000),linspace(A11, A22,1000),1);
L34 = polyfit(linspace(A4, A3,1000),linspace(A44, A33,1000),1);
P.L12 = L12;
P.L34 = L34;

%%
qHigh = 80/3600;
qExt  = 135/3600;
Q = linspace(0,qHigh,1000);
resolution = qHigh/1000;
QExtended = linspace(0,qExt,qExt/resolution);


dp1 = zeros(1,size(Q,2));
dp2 = zeros(1,size(Q,2));

% Create a set of discrete dp values of the Q-interval
for i=1:size(Q,2)
    dp1(i) = dpESPBounds(Q(i), f1, P);
    dp2(i) = dpESPBounds(Q(i), f2, P);
end
Intersect12 = [65.34 181.25];    % Line A1-A2 polynomial
Intersect23 = [113.74 138.07];    % Line A2-A3 polynomial
Intersect34 = [64.55 36.817];    % Line A3-A4 polynomial
Intersect14 = [33.518 53.1692];    % Line A1-A4 polynomial

% Fit a polynomial of degree 7 to the set of discrete dp values
% polyFitDp1 = polyfit(1:size(Q,2),dp1*10^-5,7);save('polyFitDp1','polyFitDp1');
% polyFitDp2 = polyfit(1:size(Q,2),dp2*10^-5,7);save('polyFitDp2','polyFitDp2')

% Loading saves time and prevent warning-messages to appear on the screen
load('polyFitDp1');
load('polyFitDp2');


% Create a dp line segment based on the estimated polynomial  
polyCurveDp1 = polyval(polyFitDp1,floor((Intersect14(1)/80)*1000):ceil((Intersect34(1)/80)*1000));
polyCurveDp2 = polyval(polyFitDp2,floor((Intersect12(1)/135)*qExt/resolution):ceil((Intersect23(1)/135)*qExt/resolution));

% These polynomials amount to the straight line segments found in constraints.m      
rb = polyval(L34,linspace(Intersect34(1),Intersect23(1),1000));         % Evaluate polynomial over Q
lb = polyval(L12,linspace(Intersect14(1),Intersect12(1),1000));    % Evaluate polynomial over Q


%% Plot
Q = Q(floor((Intersect14(1)/80)*1000):ceil((Intersect34(1)/80)*1000))*3600;
QExtended = QExtended(floor((Intersect12(1)/135)*qExt/resolution):ceil((Intersect23(1)/135)*qExt/resolution))*3600;
rbQ = linspace(Intersect34(1),Intersect23(1),1000);
lbQ = linspace(Intersect14(1),Intersect12(1),1000);

P.A12Q  = lbQ;
P.A12dp = lb;
P.A23Q  = QExtended;
P.A23dp = polyCurveDp2;
P.A34Q  = rbQ; 
P.A34dp = rb;
P.A41Q  = Q;
P.A41dp = polyCurveDp1;
P.IntersectQ = [Intersect14(1),Intersect12(1),Intersect23(1),Intersect34(1)];
P.IntersectDP = [Intersect14(2),Intersect12(2),Intersect23(2),Intersect34(2)];
P.lower = polyFitDp1;
P.upper = polyFitDp2;

P.L12Q = [1/P.L12(1),-P.L12(2)/P.L12(1)];
end

