function [P] = parameters(P)

%% Control volume 1
P.beta1 = 1.5e+9;                     % [Pa]     Compressibility
P.mu_1 = 0.3;                         % [Pa*s]   Fluid viscosity cv 1
P.rho1 = 984;                         % [kg/m^3] Fluid density cv 1 
P.r1 = 0.081985330499706;             % [m]      Radius of cv 1
P.l1 = 3.078838005940556e+03;         % [m]      Length of cv 1
P.V1 = P.l1*pi*P.r1^2;                % [m^3]    Volume of cv 1
P.h_r = 1.0292e+003;                  % [m]      Reservoar depth
P.h_p = 920;                          % [m]      ESP depth
P.B0_1 = 5.752218216772682e+06;       % Friction constant B_0 for tube 1
P.B1_1 = 3.903249155428134e+07;       % Friction constant B_1 for tube 1


%% Control volume 2
P.beta2 = 1.5e+9;                     % [Pa]     Compressibility
P.mu_2 = 4;                           % [Pa*s]   Fluid viscosity cv 2
P.rho2 = 984;                         % [kg/m^3] Fluid density cv 2 
P.r2 = 0.0595;                        % [m]      Radius of cv 2
P.l2 = 9.222097306189842e+02;         % [m]      Length of cv 2
P.V2 = P.l2*pi*P.r2^2;                % [m^3]    Volume of cv 2
P.h_c = 126.5400;                     % [m]      Choke depth
P.B0_2 = 7.455247950618545e+06;       % Friction constant B_0 for cv 2
P.B1_2 = 6.264914244217266e+07;       % Friction constant B_1 for cv 2


%% Average values
P.l_bar = (P.l1 + P.l2)/2; 
P.r_bar = (P.r1*P.l1+P.r2*P.l2)/(P.l1+P.l2);
P.A_bar = pi*P.r_bar^2;
P.rho_bar = (P.rho1*P.V1+P.rho2*P.V2)/(P.V1+P.V2);


%% Controller parameters
P.dfMAX = 0.25;        % [Hz/s]  Rate limit 0.5Hz/s
P.fMax = 65;           % [Hz] Maximum frequency
P.fMin = 35;           % [Hz] Minimum frequency
P.dzMAX = 0.05/0.3;    % [%/s]   Rate limit 1%/3s
P.z_cMax = 100;        % [%] Maximum choke position
P.z_cMin = 0;          % [%] Minimum choke position
P.k_p = 0.16;          % Proportional gain
P.tauI = 0.4;          % Integral time
P.e_kPrevious = 0;     % Initial control error

%% Other
P.k = 212.54/(6e+4*sqrt(1e+5));  % [m^3/(s*sqrt(bar))] Choke constant
P.PI = 6.9651e-9;                % [m^3/(Pa*s)]        Productivity index
P.g = 9.81;                      % [m/s^2]             Gravitational acceleration
P.f_0 = 50;                      % [Hz]                ESP frequency                    
P.WC = 90;                       % [%]                 Water cut
P.dt = 0.05;                     % [s]                 Time steps
P.nStages = 64;                  % Number of stages in the pump  
P.f = 56;                        % [Hz]                Initial frequency
P.fRef = P.f;
P.z_c = 100;                     % [%]                 Initial choke position
P.z_cRef = P.z_c;


end




