%% Scale pressure and flow
p =1e-5.*p;                         % [Pa] to [Bar]
q = 3600*q;                         % [m^3/s] to [m^3/hour]
p_man =10^(-5).*p_man;              % [Pa] to [Bar]
q_man = 3600*q_man;                 % [m^3/s] to [m^3/hour]

figure;
subplot(2,2,1); hold on;
plot(Tsim,setPoint_p(1,:),'--k'); plot(Tsim,p(3,:),'k');
h = legend('$p_{_{ESP}}^{in,SP}$','$p_{_{ESP}}^{in}$');
set(h,'Interpreter','latex');
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Pressure $[bar]$','Interpreter','LaTex')
title('ESP Intake Pressure','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min(p(3,:))-5) (max(p(3,:))+5)])

subplot(2,2,2); hold on;
plot(Tsim,error_p(1,:),'k');
h = legend('$e = p_{_{ESP}}^{in,SP} - p_{_{ESP}}^{in}$');
set(h,'Interpreter','latex');
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Pressure $[bar]$','Interpreter','LaTex')
title('Control Error','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min(error_p(1,:))-0.1) (max(error_p(1,:))+0.1)])


subplot(2,2,3); hold on;
plot(Tsim,SIM_f(1,:),':k');
plot(Tsim,SIM_zc(1,:),'--k');
h = legend('$f_{_{ESP}}$','$z_c$');
set(h,'Interpreter','latex');
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Frequency $[Hz]$ / Position $[\%]$','Interpreter','LaTex')
title('Control Input','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min([SIM_f(1,:) SIM_zc(1,:)])-10) (max([SIM_f(1,:) SIM_zc(1,:)])+10)])

subplot(2,2,4); hold on;
plot(q(2,:),p(7,:),':k');
% plot(1.03381,66.4917,'ko');
plot(P1.A12Q,P1.A12dp,'k');
plot(P1.A23Q,P1.A23dp,'k');
plot(P1.A34Q,P1.A34dp,'k');
plot(P1.A41Q,P1.A41dp,'k');
xlabel('$\overline{q} \left[\frac{m^3}{h}\right]$','Interpreter','LaTex'), ylabel('$\Delta p_{_{ESP}} [bar]$','Interpreter','LaTex')
title('Operational Envelope','Interpreter','LaTex')
text(q(2,1),p(7,1),'t = 0','HorizontalAlignment','left')
text(q(2,end),p(7,end),sprintf('t = %d', floor(Tsim(end))),'HorizontalAlignment','left')
h = legend('Trajectory','Location','SouthEast');
set(h,'Interpreter','latex');
hold off;


%% Figure 2
figure;
subplot(2,2,1); hold on;
plot(Tsim,setPoint_p(2,:),'--k'); plot(Tsim,p(3+7,:),'k');
h = legend('$p_{_{ESP}}^{in,SP}$','$p_{_{ESP}}^{in}$');
set(h,'Interpreter','latex');
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Pressure $[bar]$','Interpreter','LaTex')
title('ESP Intake Pressure','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min(p(3,:))-5) (max(p(3,:))+5)])

subplot(2,2,2); hold on;
plot(Tsim,error_p(2,:),'k');
h = legend('$e = p_{_{ESP}}^{in,SP} - p_{_{ESP}}^{in}$');
set(h,'Interpreter','latex');
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Pressure $[bar]$','Interpreter','LaTex')
title('Control Error','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min(error_p(2,:))-0.1) (max(error_p(2,:))+0.1)])


subplot(2,2,3); hold on;
plot(Tsim,SIM_f(2,:),':k');
plot(Tsim,SIM_zc(2,:),'--k');
h = legend('$f_{_{ESP}}$','$z_c$');
set(h,'Interpreter','latex');
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Frequency $[Hz]$ / Position $[\%]$','Interpreter','LaTex')
title('Control Input','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min([SIM_f(2,:) SIM_zc(2,:)])-10) (max([SIM_f(2,:) SIM_zc(2,:)])+10)])

subplot(2,2,4); hold on;
plot(q(2+3,:),p(7+7,:),':k');
% plot(1.03381,66.4917,'ko');
plot(P1.A12Q,P1.A12dp,'k');
plot(P1.A23Q,P1.A23dp,'k');
plot(P1.A34Q,P1.A34dp,'k');
plot(P1.A41Q,P1.A41dp,'k');
xlabel('$\overline{q} \left[\frac{m^3}{h}\right]$','Interpreter','LaTex'), ylabel('$\Delta p_{_{ESP}} [bar]$','Interpreter','LaTex')
title('Operational Envelope','Interpreter','LaTex')
text(q(2+3,1),p(7+7,1),'t = 0','HorizontalAlignment','left')
text(q(2+3,end),p(7+7,end),sprintf('t = %d', floor(Tsim(end))),'HorizontalAlignment','left')
h = legend('Trajectory','Location','SouthEast');
set(h,'Interpreter','latex');
hold off;


%% Figure 3
figure;
subplot(3,2,1); hold on;
plot(Tsim,p(5,:),'--k')
plot(Tsim,p(7,:),'k')
plot(Tsim,p(2,:),':k')
h = legend('$p_c^{in}$','$\Delta p_{_{ESP}}$','$p_{_{FBHP}}$');
set(h,'Interpreter','latex');
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Pressure $[bar]$','Interpreter','LaTex')
title('Well 1: Pressure Profile','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min([p(5,:) p(7,:) p(2,:)])-10) (max([p(5,:) p(7,:) p(2,:)])+10)])

subplot(3,2,2); hold on;
plot(Tsim,q(2,:),'k');
h = legend('$\overline{q}$');
set(h,'Interpreter','latex');
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Flow $\left[\frac{m^3}{h}\right]$','Interpreter','LaTex')
title('Well 1: Average Flow','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min(q(2,:))-.1) (max(q(2,:))+.1)])

subplot(3,2,3); hold on;
plot(Tsim,p(12,:),'--k')
plot(Tsim,p(14,:),'k')
plot(Tsim,p(9,:),':k')
h = legend('$p_c^{in}$','$\Delta p_{_{ESP}}$','$p_{_{FBHP}}$');
set(h,'Interpreter','latex');
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Pressure $[bar]$','Interpreter','LaTex')
title('Well 2: Pressure Profile','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min([p(12,:) p(14,:) p(9,:)])-10) (max([p(12,:) p(14,:) p(9,:)])+10)])

subplot(3,2,4); hold on;
plot(Tsim,q(5,:),'k');
h = legend('$\overline{q}$');
set(h,'Interpreter','latex'),
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Flow $\left[\frac{m^3}{h}\right]$','Interpreter','LaTex')
title('Well 2: Average Flow','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min(q(5,:))-.1) (max(q(5,:))+.1)])

subplot(3,2,5); hold on;
plot(Tsim,p_man,'k')
h = legend('$p_{man}$');
set(h,'Interpreter','latex'),
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Pressure $[bar]$','Interpreter','LaTex')
title('Manifold Pressure','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min(p_man)-1) (max(p_man)+1)])

subplot(3,2,6); hold on;
plot(Tsim,q_man(1,:),'k');
plot(Tsim,q_man(2,:),'--k');
h = legend('$q_{man}$','$q_{bp}$');
set(h,'Interpreter','latex'),
xlabel('Time $[s]$','Interpreter','LaTex'), ylabel('Flow $\left[\frac{m^3}{h}\right]$','Interpreter','LaTex')
title('Flow Through Manifold and Booster-Pump','Interpreter','LaTex')
hold off; axis([0  size(Tsim,2)*dt (min([q_man(1,:) q_man(2,:)])-1) (max([q_man(1,:) q_man(2,:)])+1)])




