% This is the main function. Run this file
% to start simulation.

clc; clear all; close all;
addpath Subfunctions
addpath Data
addpath ../Generic/
addpath ../Generic/other
addpath ../Generic/Statoil
addpath ../Generic/WellModules
addpath ../Generic/ManifoldModules
addpath ../Generic/Control
addpath ../Generic/Analysis/
addpath ../Scenario
addpath ../Scenario/Subfunctions

%% Case select
% Case = 'ScenarioICase01';
% Case = 'ScenarioICase02';
% Case = 'ScenarioIICase01';
% Case = 'ScenarioIICase02';
Case = 'ScenarioIIICase01';
% Case = 'ScenarioIIICase02';
% Case = 'ScenarioIVCase01';
% Case = 'ScenarioIVCase02';
% Case = 'none';

%% Run case
switch Case
    case 'ScenarioICase01'
        disp('Simulation');
        disp('Scenario 1: Step-change in pressure set-point')
        disp('Case 1:     Operation within the operational envelope')
        N = 200;                        % [s] Horizon (Simulation)
        Ninit = 150;                     % [s] Horizon (Initialization)
        
    case 'ScenarioICase02'
        disp('Simulation');
        disp('Scenario 1: Step-change in pressure set-point')
        disp('Case 2:     Active upthrust saturation')
        N = 200;                        % [s] Horizon (Simulation)
        Ninit = 100;                     % [s] Horizon (Initialization)
        
    case 'ScenarioIICase01'
        disp('Simulation');
        disp('Scenario 2: Start-up/Shut-down of one well')
        disp('Case 1:     Start-up of Well1')
        N = 350;                        % [s] Horizon (Simulation)
        Ninit = 150;                     % [s] Horizon (Initialization)
        
    case 'ScenarioIICase02'
        disp('Simulation');
        disp('Scenario 2: Start-up/Shut-down of one well')
        disp('Case 2:     Shut-down of Well1')
        N = 350;                        % [s] Horizon (Simulation)
        Ninit = 150;                     % [s] Horizon (Initialization)      
        

    case 'ScenarioIIICase01'
        disp('Simulation');
        disp('Scenario 3: ESP tripping')
        disp('Case 1:     ESP tripping in Well1')
        N = 150;                        % [s] Horizon (Simulation)
        Ninit = 100;                    % [s] Horizon (Initialization)  
             
    case 'ScenarioIVCase01'
        disp('Simulation');
        disp('Scenario 4: Start-up/Shut-down of Booster-Pump')
        disp('Case 1:     Start-up of booster-pump')
        N = 250;                        % [s] Horizon (Simulation)
        Ninit = 150;                    % [s] Horizon (Initialization) 
   case 'ScenarioIVCase02'
        disp('Simulation');
        disp('Scenario 4: Start-up/Shut-down of Booster Pump')
        disp('Case 2:     Shut-down of booster pump')
        N = 250;                        % [s] Horizon (Simulation)
        Ninit = 100;                    % [s] Horizon (Initialization) 
    otherwise
        N = 50;                        % [s] Horizon (Simulation)
        Ninit = 50;                    % [s] Horizon (Initialization) 
           
end
    

%% Simmulation parameters
dt = 0.05;                      % [s] Sampling intervall 
n_solver = 2;                          % Resolution of nummerical solver
Tsolver = 0:dt:n_solver*dt;            % Horizon used in numerical solver
Tsim = 0:dt:N;                  % Time horizon 
Nwells = 4;                     % Number of wells

%% Create wells and manifold/transportation line
P1 = CreateWell();
P2 = CreateWell();
P3 = CreateWell();
P4 = CreateWell();
[M,P1,P2,P3,P4] = CreateManifold(27e5,P1,P2,P3,P4);

%% Create data vectors used to store simulation results
createDataVectors;


%% Simulate scenario
switch Case
    case 'ScenarioICase01'
        ScenarioICase01;
        
    case 'ScenarioICase02'
        ScenarioICase02;
        
    case 'ScenarioIICase01'
        ScenarioIICase01;
    
    case 'ScenarioIICase02'
        ScenarioIICase02;
        
    case 'ScenarioIIICase01'
        ScenarioIIICase01;
        
    case 'ScenarioIVCase01'
        ScenarioIVCase01;
        
    case 'ScenarioIVCase02'
        ScenarioIVCase02;
        
    otherwise
        disp('No case selected.')
        disp('Continuing simulation with initial parameters.')
        simulation;   
   
end

%% Plot
draw;


    
    
    